aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/remoteproc/qcom_adsp_pil.c
diff options
context:
space:
mode:
authorAvaneesh Kumar Dwivedi <akdwived@codeaurora.org>2017-01-30 20:33:08 +0530
committerBjorn Andersson <bjorn.andersson@linaro.org>2017-01-30 13:48:41 -0800
commit90a068ed3fc93e088d8a216826e33b0c14edec59 (patch)
treeb220975ae8394b85960b1659e16fb6dd2012759e /drivers/remoteproc/qcom_adsp_pil.c
parentremoteproc: qcom: Add additional agree2_clk and px regulator resource. (diff)
downloadlinux-dev-90a068ed3fc93e088d8a216826e33b0c14edec59.tar.xz
linux-dev-90a068ed3fc93e088d8a216826e33b0c14edec59.zip
remoteproc: qcom: Add SLPI rproc support to load and boot slpi proc.
This patch add slpi remoteproc support in existing adsp rproc driver. Signed-off-by: Avaneesh Kumar Dwivedi <akdwived@codeaurora.org> [bjorn: documented aggre2 and px-supply] Signed-off-by: Bjorn Andersson <bjorn.andersson@linaro.org>
Diffstat (limited to 'drivers/remoteproc/qcom_adsp_pil.c')
-rw-r--r--drivers/remoteproc/qcom_adsp_pil.c10
1 files changed, 9 insertions, 1 deletions
diff --git a/drivers/remoteproc/qcom_adsp_pil.c b/drivers/remoteproc/qcom_adsp_pil.c
index 87f8d4069500..a65351ea1889 100644
--- a/drivers/remoteproc/qcom_adsp_pil.c
+++ b/drivers/remoteproc/qcom_adsp_pil.c
@@ -1,5 +1,5 @@
/*
* Qualcomm ADSP Peripheral Image Loader for MSM8974 and MSM8996
*
* Copyright (C) 2016 Linaro Ltd
* Copyright (C) 2014 Sony Mobile Communications AB
@@ -459,9 +459,17 @@ static const struct adsp_data adsp_resource_init = {
.has_aggre2_clk = false,
};
+static const struct adsp_data slpi_resource_init = {
+ .crash_reason_smem = 424,
+ .firmware_name = "slpi.mdt",
+ .pas_id = 12,
+ .has_aggre2_clk = true,
+};
+
static const struct of_device_id adsp_of_match[] = {
{ .compatible = "qcom,msm8974-adsp-pil", .data = &adsp_resource_init},
{ .compatible = "qcom,msm8996-adsp-pil", .data = &adsp_resource_init},
+ { .compatible = "qcom,msm8996-slpi-pil", .data = &slpi_resource_init},
{ },
};
MODULE_DEVICE_TABLE(of, adsp_of_match);
@@ -1,5 +1,5 @@
/*
- * Qualcomm ADSP Peripheral Image Loader for MSM8974 and MSM8996
+ * Qualcomm ADSP/SLPI Peripheral Image Loader for MSM8974 and MSM8996
*
* Copyright (C) 2016 Linaro Ltd